@@ -417,6 +417,7 @@ properties_add_for_key (GPtrArray *properties,
     {
     case GRL_METADATA_KEY_ID:
       g_ptr_array_add (properties, "UDN");
+      break;
     case GRL_METADATA_KEY_TITLE:
       g_ptr_array_add (properties, "DisplayName");
       break;
@@ -1204,7 +1205,7 @@ grl_dleyna_source_new (GrlDleynaServer *server)
   }
 
   location = grl_dleyna_media_device_get_location (device);
-  grl_dleyna_util_uri_is_localhost (location, &localhost, &localuser);
+  grl_dleyna_util_uri_is_localhost (location, &localuser, &localhost);
   i = 0;
   if (localhost) {
     tags[i++] = "localhost";
