@@ -265,13 +265,17 @@ grl_util_add_table_to_media (lua_State *L,
     lua_gettable (L, -2);
     switch (type) {
     case G_TYPE_INT:
-      if (lua_isnumber (L, -1))
-        grl_data_add_int (GRL_DATA (media), key_id, lua_tointeger (L, -1));
-      break;
-
     case G_TYPE_INT64:
-      if (lua_isnumber (L, -1))
-        grl_data_add_int64 (GRL_DATA (media), key_id, lua_tointeger (L, -1));
+      if (lua_isnumber (L, -1)) {
+        gint success;
+        gint64 value = lua_tointegerx (L, -1, &success);
+        if (success) {
+          if (type == G_TYPE_INT)
+            grl_data_add_int (GRL_DATA (media), key_id, value);
+          else
+            grl_data_add_int64 (GRL_DATA (media), key_id, value);
+        }
+      }
       break;
 
     case G_TYPE_FLOAT:
@@ -348,13 +352,24 @@ grl_util_build_media (lua_State *L,
 
       switch (type) {
       case G_TYPE_INT:
+      case G_TYPE_INT64:
         if (lua_isnumber (L, -1)) {
-          grl_data_set_int (GRL_DATA (media), key_id, lua_tointeger (L, -1));
+          gint success;
+          gint64 value = lua_tointegerx (L, -1, &success);
+          if (success) {
+            if (type == G_TYPE_INT)
+              grl_data_set_int (GRL_DATA (media), key_id, value);
+            else
+              grl_data_set_int64 (GRL_DATA (media), key_id, value);
+          } else {
+            GRL_WARNING ("'%s' requires an INT type, while a value '%s' was provided",
+                       key_name, lua_tostring(L, -1));
+          }
         } else if (lua_istable (L, -1)) {
           grl_util_add_table_to_media (L, media, key_id, key_name, type);
         } else if (!lua_isnil (L, -1)) {
           GRL_WARNING ("'%s' is not compatible for '%s'",
-                       lua_typename (L, -1), key_name);
+                       lua_typename (L, lua_type(L, -1)), key_name);
         }
         break;
 
@@ -365,18 +380,7 @@ grl_util_build_media (lua_State *L,
           grl_util_add_table_to_media (L, media, key_id, key_name, type);
         } else if (!lua_isnil (L, -1)) {
           GRL_WARNING ("'%s' is not compatible for '%s'",
-                       lua_typename (L, -1), key_name);
-        }
-        break;
-
-      case G_TYPE_INT64:
-        if (lua_isnumber (L, -1)) {
-          grl_data_set_int64 (GRL_DATA (media), key_id, lua_tointeger (L, -1));
-        } else if (lua_istable (L, -1)) {
-          grl_util_add_table_to_media (L, media, key_id, key_name, type);
-        } else if (!lua_isnil (L, -1)) {
-          GRL_WARNING ("'%s' is not compatible for '%s'",
-                       lua_typename (L, -1), key_name);
+                       lua_typename (L, lua_type(L, -1)), key_name);
         }
         break;
 
@@ -387,7 +391,7 @@ grl_util_build_media (lua_State *L,
           grl_util_add_table_to_media (L, media, key_id, key_name, type);
         } else if (!lua_isnil (L, -1)) {
           GRL_WARNING ("'%s' is not compatible for '%s'",
-                       lua_typename (L, -1), key_name);
+                       lua_typename (L, lua_type(L, -1)), key_name);
         }
         break;
       case G_TYPE_BOOLEAN:
@@ -395,7 +399,7 @@ grl_util_build_media (lua_State *L,
           grl_data_set_boolean (GRL_DATA (media), key_id, lua_toboolean (L, -1));
         } else if (!lua_isnil (L, -1)) {
           GRL_WARNING ("'%s' is not compatible for '%s'",
-                       lua_typename (L, -1), key_name);
+                       lua_typename (L, lua_type(L, -1)), key_name);
         }
         break;
 
@@ -897,6 +901,92 @@ grl_l_operation_get_keys (lua_State *L)
   return 1;
 }
 
+static gboolean
+push_grl_media_key (lua_State *L,
+                    GrlMedia *media,
+                    GrlKeyID key_id)
+{
+  GrlRegistry *registry;
+  GType type;
+  const gchar *key_name;
+  guint i, num_values;
+  gboolean is_array = FALSE;
+
+  registry = grl_registry_get_default ();
+  type = grl_registry_lookup_metadata_key_type (registry, key_id);
+  key_name = grl_registry_lookup_metadata_key_name (registry, key_id);
+
+  num_values = grl_data_length (GRL_DATA (media), key_id);
+  if (num_values  == 0)  {
+    GRL_DEBUG ("Key %s has no data", key_name);
+    return FALSE;
+  } else if (num_values > 1) {
+    is_array = TRUE;
+    lua_createtable (L, num_values, 0);
+  }
+
+  for (i = 0; i < num_values; i++) {
+    GrlRelatedKeys *relkeys;
+    const GValue *val;
+
+    relkeys = grl_data_get_related_keys (GRL_DATA (media), key_id, i);
+    if (!relkeys) {
+      GRL_DEBUG ("Key %s failed to retrieve data at index %d due NULL GrlRelatedKeys",
+                 key_name, i);
+      continue;
+    }
+
+    val = grl_related_keys_get (relkeys, key_id);
+    if (!val) {
+      GRL_DEBUG ("Key %s failed to retrieve data at index %d due NULL GValue",
+                 key_name, i);
+      continue;
+    }
+
+    if (is_array)
+      lua_pushinteger (L, i + 1);
+
+    switch (type) {
+    case G_TYPE_INT:
+      lua_pushinteger (L, g_value_get_int (val));
+      break;
+    case G_TYPE_FLOAT:
+      lua_pushnumber (L, g_value_get_float (val));
+      break;
+    case G_TYPE_STRING:
+      lua_pushstring (L, g_value_get_string (val));
+      break;
+    case G_TYPE_INT64:
+      lua_pushinteger (L, g_value_get_int64 (val));
+      break;
+    case G_TYPE_BOOLEAN:
+      lua_pushboolean (L, g_value_get_boolean (val));
+      break;
+    default:
+      if (type == G_TYPE_DATE_TIME) {
+        GDateTime *date = g_value_get_boxed (val);
+        gchar *date_str = g_date_time_format (date, "%F %T");
+        lua_pushstring (L, date_str);
+        g_free(date_str);
+      } else {
+        GRL_DEBUG ("Key %s has unhandled G_TYPE. Lua source will miss this data",
+                   key_name);
+        goto fail;
+      }
+    }
+
+    if (is_array)
+      lua_settable (L, -3);
+  }
+  return TRUE;
+
+fail:
+  if (is_array)
+    lua_pop (L, 1);
+
+  return FALSE;
+}
+
 /**
 * grl.get_media_keys
 *
@@ -916,58 +1006,28 @@ grl_l_media_get_keys (lua_State *L)
   registry = grl_registry_get_default ();
   lua_newtable (L);
   list_keys = grl_data_get_keys (GRL_DATA (os->media));
-  for (it = list_keys; it; it = g_list_next (it)) {
+  for (it = list_keys; it != NULL; it = it->next) {
     GrlKeyID key_id;
     gchar *key_name;
     gchar *ptr = NULL;
-    GType type = G_TYPE_NONE;
 
     key_id = GRLPOINTER_TO_KEYID (it->data);
+    if (key_id == GRL_METADATA_KEY_INVALID)
+      continue;
+
     key_name = g_strdup (grl_registry_lookup_metadata_key_name (registry,
                                                                 key_id));
-    key_id = grl_registry_lookup_metadata_key (registry, key_name);
-
     /* Replace '-' to '_': as a convenience for the developer */
     while ((ptr = strstr (key_name, "-")) != NULL) {
       *ptr = '_';
     }
 
     lua_pushstring (L, key_name);
-    if (key_id != GRL_METADATA_KEY_INVALID) {
-      type = grl_registry_lookup_metadata_key_type (registry, key_id);
-      switch (type) {
-      case G_TYPE_INT:
-        lua_pushnumber (L, grl_data_get_int (GRL_DATA (os->media), key_id));
-        break;
-      case G_TYPE_FLOAT:
-        lua_pushnumber (L, grl_data_get_float (GRL_DATA (os->media), key_id));
-        break;
-      case G_TYPE_STRING:
-        lua_pushstring (L, grl_data_get_string (GRL_DATA (os->media), key_id));
-        break;
-      case G_TYPE_INT64:
-        lua_pushnumber (L, grl_data_get_int64 (GRL_DATA (os->media), key_id));
-        break;
-      case G_TYPE_BOOLEAN:
-        lua_pushboolean (L, grl_data_get_boolean (GRL_DATA (os->media), key_id));
-        break;
-      default:
-        if (type == G_TYPE_DATE_TIME) {
-          GDateTime *date = grl_data_get_boxed (GRL_DATA (os->media), key_id);
-          gchar *date_str = g_date_time_format (date, "%F %T");
-          lua_pushstring (L, date_str);
-          g_free(date_str);
-
-        } else {
-          GRL_DEBUG ("'%s' is being ignored as G_TYPE is not being handled.",
-                     key_name);
-          g_free (key_name);
-          lua_pop (L, 1);
-          continue;
-        }
-      }
+    if (push_grl_media_key (L, os->media, key_id))
       lua_settable (L, -3);
-    }
+    else
+      lua_pop (L, 1);
+
     g_free (key_name);
   }
   g_list_free (list_keys);
@@ -992,12 +1052,15 @@ grl_l_fetch (lua_State *L)
   const gchar *lua_callback;
   GrlNetWc *wc;
   gboolean is_table = FALSE;
+  gboolean wc_options = FALSE;
   OperationSpec *os;
 
   luaL_argcheck (L, (lua_isstring (L, 1) || lua_istable (L, 1)), 1,
                  "expecting url as string or an array of urls");
   luaL_argcheck (L, lua_isstring (L, 2), 2,
                  "expecting callback function as string");
+  /* Optional third argument */
+  wc_options = (lua_gettop(L) == 3);
 
   os = grl_lua_library_get_current_operation (L);
   g_return_val_if_fail (os != NULL, 0);
@@ -1035,7 +1098,7 @@ grl_l_fetch (lua_State *L)
 
   lua_callback = lua_tolstring (L, 2, NULL);
 
-  wc = net_wc_new_with_options(L, 3);
+  wc = (wc_options) ? net_wc_new_with_options(L, 3) : grl_net_wc_new ();
 
   /* shared data between urls */
   results = g_new0 (gchar *, num_urls);
@@ -1479,6 +1542,10 @@ luaopen_grilo (lua_State *L)
   luaopen_json (L);
   lua_settable (L, -3);
 
+  lua_pushstring (L, GRILO_LUA_LIBRARY_XML);
+  luaopen_xml (L);
+  lua_settable (L, -3);
+
   /* Load inspect.lua and save object in global environment table */
   lua_getglobal (L, LUA_ENV_TABLE);
   if (load_gresource_library (L, URI_LUA_LIBRARY_INSPECT) &&
