@@ -326,11 +326,16 @@ GRL_PLUGIN_REGISTER (grl_podcasts_plugin_init,
 static GrlPodcastsSource *
 grl_podcasts_source_new (void)
 {
+  const char *tags[] = {
+    "net:internet",
+    NULL
+  };
   GRL_DEBUG ("grl_podcasts_source_new");
   return g_object_new (GRL_PODCASTS_SOURCE_TYPE,
 		       "source-id", SOURCE_ID,
 		       "source-name", SOURCE_NAME,
 		       "source-desc", SOURCE_DESC,
+		       "source-tags", tags,
 		       NULL);
 }
 
@@ -383,6 +388,7 @@ grl_podcasts_source_init (GrlPodcastsSource *source)
     g_critical ("Failed to open database '%s': %s",
 		db_path, sqlite3_errmsg (source->priv->db));
     sqlite3_close (source->priv->db);
+    source->priv->db = NULL;
     return;
   }
   GRL_DEBUG ("  OK");
@@ -404,6 +410,7 @@ grl_podcasts_source_init (GrlPodcastsSource *source)
       GRL_WARNING ("Failed to create database tables.");
     }
     sqlite3_close (source->priv->db);
+    source->priv->db = NULL;
     return;
   }
   GRL_DEBUG ("  OK");
@@ -422,7 +429,8 @@ grl_podcasts_source_finalize (GObject *object)
 
   g_clear_object (&source->priv->wc);
 
-  sqlite3_close (source->priv->db);
+  if (source->priv->db)
+    sqlite3_close (source->priv->db);
 
   G_OBJECT_CLASS (grl_podcasts_source_parent_class)->finalize (object);
 }
