@@ -153,6 +153,19 @@ grl_tmdb_source_plugin_init (GrlRegistry *registry,
     return FALSE;
   }
 
+  GrlTmdbSource *source = grl_tmdb_source_new (api_key);
+  grl_registry_register_source (registry,
+                                       plugin,
+                                       GRL_SOURCE (source),
+                                       NULL);
+  g_free (api_key);
+  return TRUE;
+}
+
+static void
+grl_tmdb_source_plugin_register_keys (GrlRegistry *registry,
+                                      GrlPlugin   *plugin)
+{
   GRL_TMDB_METADATA_KEY_BACKDROP =
     register_metadata_key (registry,
                            "tmdb-backdrop",
@@ -176,31 +189,30 @@ grl_tmdb_source_plugin_init (GrlRegistry *registry,
                            "tmdb-id",
                            "tmdb-id",
                            "ID of this movie at tmdb.org");
-
-  GrlTmdbSource *source = grl_tmdb_source_new (api_key);
-  grl_registry_register_source (registry,
-                                       plugin,
-                                       GRL_SOURCE (source),
-                                       NULL);
-  g_free (api_key);
-  return TRUE;
 }
 
-GRL_PLUGIN_REGISTER (grl_tmdb_source_plugin_init,
-                     NULL,
-                     PLUGIN_ID);
+GRL_PLUGIN_REGISTER_FULL (grl_tmdb_source_plugin_init,
+                          NULL,
+                          grl_tmdb_source_plugin_register_keys,
+                          PLUGIN_ID);
 
 /* ================== GrlTmdbMetadata GObject ================ */
 
 static GrlTmdbSource *
 grl_tmdb_source_new (const char *api_key)
 {
+  const char *tags[] = {
+    "cinema",
+    "net:internet",
+    NULL
+  };
   GRL_DEBUG ("grl_tmdb_source_new");
   return g_object_new (GRL_TMDB_SOURCE_TYPE,
                        "source-id", SOURCE_ID,
                        "source-name", SOURCE_NAME,
                        "source-desc", SOURCE_DESC,
                        "api-key", api_key,
+                       "source-tags", tags,
                        NULL);
 }
 
@@ -383,7 +395,6 @@ register_metadata_key (GrlRegistry *registry,
                               | G_PARAM_STATIC_STRINGS);
 
   key = grl_registry_register_metadata_key (registry, spec, NULL);
-  g_param_spec_unref (spec);
 
   if (key == GRL_METADATA_KEY_INVALID) {
     key = grl_registry_lookup_metadata_key (registry, name);
@@ -717,6 +728,7 @@ on_request_ready (GObject *source,
     value = grl_tmdb_request_get (request, "$.title");
     if (value != NULL) {
       grl_media_set_title (closure->rs->media, g_value_get_string (value));
+      grl_data_set_boolean (GRL_DATA (closure->rs->media), GRL_METADATA_KEY_TITLE_FROM_FILENAME, FALSE);
       g_value_unset (value);
       g_free (value);
     }
@@ -1004,6 +1016,7 @@ on_search_ready (GObject *source,
     value = grl_tmdb_request_get (request, "$.results[0].title");
     if (value) {
       grl_media_set_title (closure->rs->media, g_value_get_string (value));
+      grl_data_set_boolean (GRL_DATA (closure->rs->media), GRL_METADATA_KEY_TITLE_FROM_FILENAME, FALSE);
       g_value_unset (value);
       g_free (value);
     }
@@ -1297,6 +1310,12 @@ grl_tmdb_source_resolve (GrlSource *source,
     return;
   }
 
+  /* If the media is a TV show, don't handle it */
+  if (grl_media_video_get_show (GRL_MEDIA_VIDEO (rs->media)) != NULL) {
+    rs->callback (source, rs->operation_id, rs->media, rs->user_data, NULL);
+    return;
+  }
+
   /* Prefer resolving by movie-id: This is more reliable and saves the search query. */
   str_movie_id = grl_data_get_string (GRL_DATA (rs->media),
                                       GRL_TMDB_METADATA_KEY_TMDB_ID);
@@ -1338,7 +1357,7 @@ grl_tmdb_source_resolve (GrlSource *source,
 
   /* Disable slow resolution if slow keys where requested, but the operation
    * options explicitly ask for fast resolving only. */
-  if (grl_operation_options_get_flags (rs->options) & GRL_RESOLVE_FAST_ONLY)
+  if (grl_operation_options_get_resolution_flags (rs->options) & GRL_RESOLVE_FAST_ONLY)
     closure->slow = FALSE;
 
   /* We did not receive the config yet, queue request. Config callback will
