@@ -1021,6 +1021,16 @@ grl_tracker_source_search (GrlSource *source, GrlSourceSearchSpec *ss)
   g_free (duration_constraint);
 }
 
+static gboolean
+is_root_box (GrlMedia *container)
+{
+  if (container == NULL)
+    return TRUE;
+  if (!grl_media_get_id (container))
+    return TRUE;
+  return FALSE;
+}
+
 static void
 grl_tracker_source_browse_category (GrlSource *source,
                                     GrlSourceBrowseSpec *bs)
@@ -1041,7 +1051,43 @@ grl_tracker_source_browse_category (GrlSource *source,
 
   GRL_IDEBUG ("%s: id=%u", __FUNCTION__, bs->operation_id);
 
-  if (bs->container == NULL ||
+  /* If the category is missing, try to get it from the
+   * container's ID */
+  if (!is_root_box (bs->container) &&
+      !grl_data_has_key (GRL_DATA (bs->container),
+                         grl_metadata_key_tracker_category)) {
+    const char *id;
+
+    id = grl_media_get_id (bs->container);
+    if (g_strcmp0 (id, "documents") == 0)
+      category = "nfo:Document";
+    else if (g_strcmp0 (id, "music") == 0)
+      category = "nmm:MusicPiece";
+    else if (g_strcmp0 (id, "photos") == 0)
+      category = "nmm:Photo";
+    else if (g_strcmp0 (id, "videos") == 0)
+      category = "nmm:Video";
+    else {
+      GError *error;
+
+      error = g_error_new (GRL_CORE_ERROR,
+                           GRL_CORE_ERROR_BROWSE_FAILED,
+                           _("ID '%s' is not known in this source"),
+                           id);
+
+      bs->callback (bs->source, bs->operation_id, NULL, 0,
+                    bs->user_data, error);
+
+      g_error_free (error);
+      return;
+    }
+
+    grl_data_set_string (GRL_DATA (bs->container),
+                         grl_metadata_key_tracker_category,
+                         category);
+  }
+
+  if (is_root_box (bs->container) ||
       !grl_data_has_key (GRL_DATA (bs->container),
                          grl_metadata_key_tracker_category)) {
     /* Hardcoded categories */
@@ -1083,6 +1129,7 @@ grl_tracker_source_browse_category (GrlSource *source,
       if (remaining == 4) {
         media = grl_media_box_new ();
         grl_media_set_title (media, "Documents");
+        grl_media_set_id (media, "documents");
         grl_data_set_string (GRL_DATA (media),
                              grl_metadata_key_tracker_category,
                              "nfo:Document");
@@ -1093,6 +1140,7 @@ grl_tracker_source_browse_category (GrlSource *source,
       if (filter & GRL_TYPE_FILTER_AUDIO) {
         media = grl_media_box_new ();
         grl_media_set_title (media, "Music");
+        grl_media_set_id (media, "music");
         grl_data_set_string (GRL_DATA (media),
                              grl_metadata_key_tracker_category,
                              "nmm:MusicPiece");
@@ -1103,6 +1151,7 @@ grl_tracker_source_browse_category (GrlSource *source,
       if (filter & GRL_TYPE_FILTER_IMAGE) {
         media = grl_media_box_new ();
         grl_media_set_title (media, "Photos");
+        grl_media_set_id (media, "photos");
         grl_data_set_string (GRL_DATA (media),
                              grl_metadata_key_tracker_category,
                              "nmm:Photo");
@@ -1113,6 +1162,7 @@ grl_tracker_source_browse_category (GrlSource *source,
       if (filter & GRL_TYPE_FILTER_VIDEO) {
         media = grl_media_box_new ();
         grl_media_set_title (media, "Videos");
+        grl_media_set_id (media, "videos");
         grl_data_set_string (GRL_DATA (media),
                              grl_metadata_key_tracker_category,
                              "nmm:Video");
@@ -1218,6 +1268,10 @@ void
 grl_tracker_source_browse (GrlSource *source,
                            GrlSourceBrowseSpec *bs)
 {
+  /* Ensure GRL_METADATA_KEY_ID is always requested */
+  if (!g_list_find (bs->keys, GRLKEYID_TO_POINTER (GRL_METADATA_KEY_ID)))
+    bs->keys = g_list_prepend (bs->keys, GRLKEYID_TO_POINTER (GRL_METADATA_KEY_ID));
+
   if (grl_tracker_browse_filesystem)
     grl_tracker_source_browse_filesystem (source, bs);
   else
@@ -1375,6 +1429,10 @@ grl_tracker_source_get_media_from_uri (GrlSource *source,
 
   GRL_IDEBUG ("%s: id=%u", __FUNCTION__, mfus->operation_id);
 
+  /* Ensure GRL_METADATA_KEY_ID is always requested */
+  if (!g_list_find (mfus->keys, GRLKEYID_TO_POINTER (GRL_METADATA_KEY_ID)))
+    mfus->keys = g_list_prepend (mfus->keys, GRLKEYID_TO_POINTER (GRL_METADATA_KEY_ID));
+
   constraint = grl_tracker_source_get_device_constraint (priv);
   sparql_select = grl_tracker_source_get_select_string (mfus->keys);
   sparql_final = g_strdup_printf (TRACKER_MEDIA_FROM_URI_REQUEST,
