@@ -123,8 +123,8 @@ typedef void (*AsyncReadCbFunc) (gchar *data, gpointer user_data);
 typedef void (*BuildMediaFromEntryCbFunc) (GrlMedia *media, gpointer user_data);
 
 typedef struct {
-  gchar *id;
-  gchar *name;
+  const gchar *id;
+  const gchar *name;
   guint count;
 } CategoryInfo;
 
@@ -143,10 +143,11 @@ typedef struct {
   CategoryInfo *category_info;
   guint emitted;
   guint matches;
-  guint ref_count;
+  gint ref_count;
 } OperationSpec;
 
 typedef struct {
+  GrlSource *source;
   GSourceFunc callback;
   gpointer user_data;
 } BuildCategorySpec;
@@ -217,7 +218,7 @@ static void grl_youtube_get_media_from_uri (GrlSource *source,
 static void grl_youtube_source_cancel (GrlSource *source,
                                        guint operation_id);
 
-static void produce_from_directory (CategoryInfo *dir, gint dir_size, OperationSpec *os);
+static void produce_from_directory (CategoryInfo *dir, guint dir_size, OperationSpec *os);
 
 /* ==================== Global Data  ================= */
 
@@ -285,13 +286,6 @@ grl_youtube_plugin_init (GrlRegistry *registry,
   }
   format = grl_config_get_string (config, "format");
 
-#if !GLIB_CHECK_VERSION(2,32,0)
-  /* libgdata needs this */
-  if (!g_thread_supported()) {
-    g_thread_init (NULL);
-  }
-#endif
-
   source = grl_youtube_source_new (api_key, YOUTUBE_CLIENT_ID, format);
 
   grl_registry_register_source (registry,
@@ -457,7 +451,7 @@ operation_spec_new (void)
   GRL_DEBUG ("Allocating new spec");
 
   os =  g_slice_new0 (OperationSpec);
-  os->ref_count = 1;
+  g_atomic_int_set (&os->ref_count, 1);
 
   return os;
 }
@@ -465,8 +459,7 @@ operation_spec_new (void)
 static void
 operation_spec_unref (OperationSpec *os)
 {
-  os->ref_count--;
-  if (os->ref_count == 0) {
+  if (g_atomic_int_dec_and_test (&os->ref_count)) {
     g_clear_object (&os->cancellable);
     g_slice_free (OperationSpec, os);
     GRL_DEBUG ("freeing spec");
@@ -477,71 +470,7 @@ static void
 operation_spec_ref (OperationSpec *os)
 {
   GRL_DEBUG ("Reffing spec");
-  os->ref_count++;
-}
-
-inline static GrlNetWc *
-get_wc (void)
-{
-  if (ytsrc && !ytsrc->priv->wc)
-    ytsrc->priv->wc = grl_net_wc_new ();
-  else if (!ytsrc)
-    return NULL;
-
-  return ytsrc->priv->wc;
-}
-
-static void
-read_done_cb (GObject *source_object,
-              GAsyncResult *res,
-              gpointer user_data)
-{
-  AsyncReadCb *arc = (AsyncReadCb *) user_data;
-  GError *wc_error = NULL;
-  gchar *content = NULL;
-
-  grl_net_wc_request_finish (GRL_NET_WC (source_object),
-                         res,
-                         &content,
-                         NULL,
-                         &wc_error);
-  if (wc_error) {
-    if (wc_error->code != GRL_NET_WC_ERROR_CANCELLED) {
-      GRL_WARNING ("Failed to open '%s': %s", arc->url, wc_error->message);
-    }
-    arc->callback (NULL, arc->user_data);
-    g_error_free (wc_error);
-  } else {
-    arc->callback (content, arc->user_data);
-  }
-  g_free (arc->url);
-  g_slice_free (AsyncReadCb, arc);
-}
-
-static void
-read_url_async (const gchar *url,
-                GCancellable *cancellable,
-                AsyncReadCbFunc callback,
-                gpointer user_data)
-{
-  AsyncReadCb *arc;
-  GrlNetWc *wc;
-
-  wc = get_wc ();
-  if (!wc)
-    return;
-
-  arc = g_slice_new0 (AsyncReadCb);
-  arc->url = g_strdup (url);
-  arc->callback = callback;
-  arc->user_data = user_data;
-
-  GRL_DEBUG ("Opening async '%s'", url);
-  grl_net_wc_request_async (wc,
-                        url,
-                        cancellable,
-                        read_done_cb,
-                        arc);
+  g_atomic_int_inc (&os->ref_count);
 }
 
 static void
@@ -643,24 +572,45 @@ build_media_from_entry (GrlYoutubeSource *source,
 }
 
 static void
-parse_categories (xmlDocPtr doc, xmlNodePtr node, BuildCategorySpec *bcs)
+build_categories_directory_read_cb (GObject *source_object,
+                                    GAsyncResult *result,
+                                    gpointer user_data)
 {
+  GDataYouTubeService *service;
+  BuildCategorySpec *bcs;
+  GDataAPPCategories *app_categories = NULL;
+  GList *categories = NULL;  /*<unowned GDataCategory>*/
+  GError *error = NULL;
   guint total = 0;
   GList *all = NULL, *iter;
   CategoryInfo *cat_info;
   gchar *id;
   guint index = 0;
 
-  GRL_DEBUG ("parse_categories");
+  GRL_DEBUG (G_STRFUNC);
+
+  service = GDATA_YOUTUBE_SERVICE (source_object);
+  bcs = user_data;
+
+  app_categories = gdata_youtube_service_get_categories_finish (service,
+                                                                result,
+                                                                &error);
+
+  if (error != NULL) {
+    g_error_free (error);
+    goto done;
+  }
+
+  categories = gdata_app_categories_get_categories (app_categories);
+
+  for (; categories != NULL; categories = categories->next) {
+    GDataCategory *category = GDATA_CATEGORY (categories->data);
 
-  while (node) {
     cat_info = g_slice_new (CategoryInfo);
-    id = (gchar *) xmlGetProp (node, (xmlChar *) "term");
-    cat_info->id = g_strconcat (YOUTUBE_CATEGORIES_ID, "/", id, NULL);
-    cat_info->name = (gchar *) xmlGetProp (node, (xmlChar *) "label");
+    cat_info->id = g_strconcat (YOUTUBE_CATEGORIES_ID, "/",
+                                gdata_category_get_term (category), NULL);
+    cat_info->name = g_strdup (gdata_category_get_label (category));
     all = g_list_prepend (all, cat_info);
-    g_free (id);
-    node = node->next;
     total++;
     GRL_DEBUG ("  Found category: '%d - %s'", index++, cat_info->name);
   }
@@ -680,51 +630,11 @@ parse_categories (xmlDocPtr doc, xmlNodePtr node, BuildCategorySpec *bcs)
       iter = g_list_next (iter);
     } while (iter);
     g_list_free (all);
-
-    bcs->callback (bcs);
-    g_slice_free (BuildCategorySpec, bcs);
-  }
-}
-
-static void
-build_categories_directory_read_cb (gchar *xmldata, gpointer user_data)
-{
-  xmlDocPtr doc;
-  xmlNodePtr node;
-
-  if (!xmldata) {
-    g_critical ("Failed to build category directory (1)");
-    return;
   }
 
-  doc = xmlReadMemory (xmldata, strlen (xmldata), NULL, NULL,
-                       XML_PARSE_RECOVER | XML_PARSE_NOBLANKS);
-  if (!doc) {
-    g_critical ("Failed to build category directory (2)");
-    goto free_resources;
-  }
-
-  node = xmlDocGetRootElement (doc);
-  if (!node) {
-    g_critical ("Failed to build category directory (3)");
-    goto free_resources;
-  }
-
-  if (xmlStrcmp (node->name, (const xmlChar *) "categories")) {
-    g_critical ("Failed to build category directory (4)");
-    goto free_resources;
-  }
-
-  node = node->xmlChildrenNode;
-  if (!node) {
-    g_critical ("Failed to build category directory (5)");
-    goto free_resources;
-  }
-
-  parse_categories (doc, node, user_data);
-
- free_resources:
-  xmlFreeDoc (doc);
+done:
+  bcs->callback (bcs);
+  g_slice_free (BuildCategorySpec, bcs);
 }
 
 static gint
@@ -762,7 +672,7 @@ get_category_term_from_id (const gchar *category_id)
 static gint
 get_category_index_from_id (const gchar *category_id)
 {
-  gint i;
+  guint i;
 
   for (i=0; i<root_dir[ROOT_DIR_CATEGORIES_INDEX].count; i++) {
     if (!strcmp (categories_dir[i].id, category_id)) {
@@ -821,12 +731,16 @@ build_media_from_entry_search_cb (GrlMedia *media, gpointer user_data)
 static void
 build_category_directory (BuildCategorySpec *bcs)
 {
+  GrlYoutubeSource *source;
+  GDataService *service;
+
   GRL_DEBUG (__FUNCTION__);
 
-  read_url_async (YOUTUBE_CATEGORIES_URL,
-                  NULL,
-                  build_categories_directory_read_cb,
-                  bcs);
+  source = GRL_YOUTUBE_SOURCE (bcs->source);
+  service = GDATA_SERVICE (source->priv->service);
+  gdata_youtube_service_get_categories_async (service, NULL,
+                                              build_categories_directory_read_cb,
+                                              bcs);
 }
 
 static void
@@ -1069,7 +983,7 @@ produce_container_from_directory (GDataService *service,
 }
 
 static void
-produce_from_directory (CategoryInfo *dir, gint dir_size, OperationSpec *os)
+produce_from_directory (CategoryInfo *dir, guint dir_size, OperationSpec *os)
 {
   guint index, remaining;
 
@@ -1150,12 +1064,14 @@ produce_from_feed (OperationSpec *os)
   operation_spec_ref (os);
 
   os->cancellable = g_cancellable_new ();
-  grl_operation_set_data (os->operation_id, os->cancellable);
+  grl_operation_set_data (os->operation_id, g_object_ref (os->cancellable));
 
   service = GRL_YOUTUBE_SOURCE (os->source)->priv->service;
 
   /* Index in GData starts at 1 */
-  query = gdata_query_new_with_limits (NULL , os->skip + 1, os->count);
+  query = gdata_youtube_query_new (NULL);
+  gdata_query_set_start_index (query, os->skip + 1);
+  gdata_query_set_max_results (query, os->count);
   os->category_info = &feeds_dir[feed_type];
 
   gdata_youtube_service_query_standard_feed_async (GDATA_YOUTUBE_SERVICE (service),
@@ -1205,7 +1121,9 @@ produce_from_category (OperationSpec *os)
   service = GRL_YOUTUBE_SOURCE (os->source)->priv->service;
 
   /* Index in GData starts at 1 */
-  query = gdata_query_new_with_limits (NULL , os->skip + 1, os->count);
+  query = gdata_youtube_query_new (NULL);
+  gdata_query_set_start_index (query, os->skip + 1);
+  gdata_query_set_max_results (query, os->count);
   os->category_info = &categories_dir[category_index];
   gdata_query_set_categories (query, category_term);
 
@@ -1389,10 +1307,12 @@ grl_youtube_source_search (GrlSource *source,
   /* Look for OPERATION_SPEC_REF_RATIONALE for details */
   operation_spec_ref (os);
 
-  grl_operation_set_data (ss->operation_id, os->cancellable);
+  grl_operation_set_data (ss->operation_id, g_object_ref (os->cancellable));
 
   /* Index in GData starts at 1 */
-  query = gdata_query_new_with_limits (ss->text, os->skip + 1, os->count);
+  query = gdata_youtube_query_new (ss->text);
+  gdata_query_set_start_index (query, os->skip + 1);
+  gdata_query_set_max_results (query, os->count);
 
   gdata_youtube_service_query_videos_async (GDATA_YOUTUBE_SERVICE (GRL_YOUTUBE_SOURCE (source)->priv->service),
                                             query,
@@ -1446,6 +1366,7 @@ grl_youtube_source_browse (GrlSource *source,
     case YOUTUBE_MEDIA_TYPE_CATEGORIES:
       if (!categories_dir) {
         bcs = g_slice_new0 (BuildCategorySpec);
+        bcs->source = bs->source;
         bcs->callback = (GSourceFunc) produce_from_category_cb;
         bcs->user_data = os;
         build_category_directory (bcs);
@@ -1514,6 +1435,7 @@ grl_youtube_source_resolve (GrlSource *source,
     {
       if (!categories_dir) {
         bcs = g_slice_new0 (BuildCategorySpec);
+        bcs->source = source;
         bcs->callback = (GSourceFunc) produce_container_from_category_cb;
         bcs->user_data = rs;
         build_category_directory (bcs);
